package mhtree;

/**
 * Specifies how new objects should be added to the MH-Tree.
 */
public enum InsertType {
    /**
     * When the inserted object is not covered by a node, all objects under such node are retrieved (recursively down to the buckets),
     * and a new hull is built, replacing the current one.
     */
    GREEDY,

    /**
     * When the inserted object is not covered by node, we iterate over hull objects beginning with the nearest one.
     * We try to replace an existing hull object by replacing it with the inserted object.
     * If the removed hull object is covered by the new hull, we are done.
     * If no such hull object is found, the inserted object is simply added as a new hull object.
     */
    INCREMENTAL,

    /** Take current hull objects and the newly inserted object and compute hull out of them.
     * Vlasta: Is this identical to INCREMENTAL?
     */
    ADD_HULL_OBJECT,
}
